@@ -11,7 +11,12 @@ if TYPE_CHECKING:
 
 
 async def is_db_available(connection: Connection, database_name: str) -> bool:
-    """Verify if the database exists."""
+    """
+    Verify that the database exists.
+
+    Args:
+        connection (firebolt.async_db.connection.Connection)
+    """
     resp = await _filter_request(
         connection, DATABASES_URL, {"filter.name_contains": database_name}
     )
@@ -19,16 +24,21 @@ async def is_db_available(connection: Connection, database_name: str) -> bool:
 
 
 async def is_engine_running(connection: Connection, engine_url: str) -> bool:
-    """Verify if the engine is running."""
-    # Url is not always guaranteed to be of this structure
-    # but for the sake of error check this is sufficient
-    engine_name = URL(engine_url).host.split(".")[0]
+    """
+    Verify that the engine is running.
+
+    Args:
+        connection (firebolt.async_db.connection.Connection): connection.
+    """
+    # Url is not guaranteed to be of this structure,
+    # but for the sake of error checking this is sufficient.
+    engine_name = URL(engine_url).host.split(".")[0].replace("-", "_")
     resp = await _filter_request(
         connection,
         ENGINES_URL,
         {
             "filter.name_contains": engine_name,
-            "filter.current_status_eq": "ENGINE_STATUS_RUNNING",
+            "filter.current_status_eq": "ENGINE_STATUS_RUNNING_REVISION_SERVING",
         },
     )
     return len(resp.json()["edges"]) > 0
@@ -38,7 +48,7 @@ async def _filter_request(
     connection: Connection, endpoint: str, filters: dict
 ) -> Response:
     resp = await connection._client.request(
-        # Full URL overrides the client url, which contains engine as a prefix
+        # Full url overrides the client url, which contains engine as a prefix.
         url=connection.api_endpoint + endpoint,
         method="GET",
         params=filters,
