@@ -1,4 +1,4 @@
-from firebolt.client.auth import Auth
+from firebolt.client.auth import Auth  # backward compatibility
 from firebolt.client.client import AsyncClient, Client
 from firebolt.client.constants import DEFAULT_API_URL
 from firebolt.client.resource_manager_hooks import (
